# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.6](https://github.com/cauliyang/DeepBioP/compare/deepbiop-bam-v0.1.5...deepbiop-bam-v0.1.6) - 2024-08-08

### Added
- Add Segment class with overlap method
- Add chimeric event module
- Add rayon and ahash dependencies, implement chimeric.rs

### Other
- Remove duplicate code for adding submodules
- Improve submodule registration method
- Add sub-module registration for deepbiop modules
- Improve chimeric read processing functions
- Update README.md setup instructions
